@@ -24,44 +24,27 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-s3-sqs`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.s3sqs`|
 
-## Overview
-
 This AWS Solutions Construct implements an Amazon S3 Bucket that is configured to send notifications to an Amazon SQS queue.
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { S3ToSqs } from "@aws-solutions-constructs/aws-s3-sqs";
+import {S3ToSqs} from "@aws-solutions-constructs/aws-s3-sqs";
 
-new S3ToSqs(this, 'S3ToSQSPattern', {});
+new S3ToSqs(stack, 'S3ToSQSPattern', {});
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_s3_sqs import S3ToSqs
-from aws_cdk import Stack
-from constructs import Construct
-
-S3ToSqs(self, 'S3ToSQSPattern')
+```text
+new S3ToSqs(scope: Construct, id: string, props: S3ToSqsProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awsconstructs.services.s3sqs.*;
-
-new S3ToSqs(this, "S3ToSQSPattern", new S3ToSqsProps.Builder()
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`S3ToSqsProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -121,7 +104,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -133,18 +116,16 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_kms
 import aws_cdk.aws_s3
 import aws_cdk.aws_sqs
-import aws_cdk.core
+import constructs
 
 
 class S3ToSqs(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-s3-sqs.S3ToSqs",
 ):
@@ -154,22 +135,22 @@ class S3ToSqs(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-        s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        s3_event_filters: typing.Optional[typing.Sequence[aws_cdk.aws_s3.NotificationKeyFilter]] = None,
         s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
     ) -> None:
         '''
@@ -194,30 +175,6 @@ class S3ToSqs(
         :since: 0.8.0
         :summary: Constructs a new instance of the S3ToSqs class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
-                s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToSqsProps(
             bucket_props=bucket_props,
             dead_letter_queue_props=dead_letter_queue_props,
@@ -237,32 +194,32 @@ class S3ToSqs(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], jsii.get(self, "encryptionKey"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -292,19 +249,19 @@ class S3ToSqsProps:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-        s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        s3_event_filters: typing.Optional[typing.Sequence[aws_cdk.aws_s3.NotificationKeyFilter]] = None,
         s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
     ) -> None:
         '''
@@ -335,40 +292,6 @@ class S3ToSqsProps:
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        if __debug__:
-            def stub(
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
-                s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
-            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
-            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
-            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
-            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
-            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
-            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
-            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
-            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
-            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
-            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
-            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
-            check_type(argname="argument s3_event_filters", value=s3_event_filters, expected_type=type_hints["s3_event_filters"])
-            check_type(argname="argument s3_event_types", value=s3_event_types, expected_type=type_hints["s3_event_types"])
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
